# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import tensorboard_service_pb2 as grid_dot_v1_dot_tensorboard__service__pb2


class TensorboardServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/CreateTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardResponse.FromString,
        )
        self.GetTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/GetTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardResponse.FromString,
        )
        self.ListTensorboards = channel.unary_unary(
            '/grid.v1.TensorboardService/ListTensorboards',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsResponse.FromString,
        )
        self.UpdateTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/UpdateTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardResponse.FromString,
        )
        self.UpdateTensorboardStatus = channel.unary_unary(
            '/grid.v1.TensorboardService/UpdateTensorboardStatus',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusRequest.
            SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusResponse.FromString,
        )
        self.DeleteTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/DeleteTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardResponse.FromString,
        )
        self.WatchTensorboards = channel.unary_stream(
            '/grid.v1.TensorboardService/WatchTensorboards',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsResponse.FromString,
        )


class TensorboardServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTensorboards(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTensorboardStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchTensorboards(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TensorboardServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardResponse.SerializeToString,
        ),
        'GetTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardResponse.SerializeToString,
        ),
        'ListTensorboards':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListTensorboards,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsResponse.SerializeToString,
        ),
        'UpdateTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardResponse.SerializeToString,
        ),
        'UpdateTensorboardStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTensorboardStatus,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusResponse.
            SerializeToString,
        ),
        'DeleteTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardResponse.SerializeToString,
        ),
        'WatchTensorboards':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchTensorboards,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.TensorboardService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
