# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import cluster_pb2 as grid_dot_v1_dot_cluster__pb2
from grid.protos.grid.v1 import logs_pb2 as grid_dot_v1_dot_logs__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/cluster_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1dgrid/v1/cluster_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x15grid/v1/cluster.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12grid/v1/logs.proto\"B\n\x14\x43reateClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15\x43reateClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"#\n\x11GetClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"@\n\x12GetClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\x8d\x04\n\x13ListClustersRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x30\n\x08phase_in\x18\x05 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\nphaseNotIn\x12?\n\x10\x64\x65sired_state_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x0e\x64\x65siredStateIn\x12\x46\n\x14\x64\x65sired_state_not_in\x18\x08 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x11\x64\x65siredStateNotIn\x12<\n\x0f\x63luster_type_in\x18\t \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\rclusterTypeIn\x12\x43\n\x13\x63luster_type_not_in\x18\n \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\x10\x63lusterTypeNotIn\"\x94\x01\n\x14ListClustersResponse\x12*\n\x07\x63luster\x18\x01 \x03(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"B\n\x14UpdateClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15UpdateClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"H\n\x1aUpdateClusterStatusRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"I\n\x1bUpdateClusterStatusResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"B\n\x14\x44\x65leteClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15\x44\x65leteClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\xe7\x03\n\x14WatchClustersRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x30\n\x08phase_in\x18\x05 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\nphaseNotIn\x12?\n\x10\x64\x65sired_state_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x0e\x64\x65siredStateIn\x12\x46\n\x14\x64\x65sired_state_not_in\x18\x08 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x11\x64\x65siredStateNotIn\x12<\n\x0f\x63luster_type_in\x18\t \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\rclusterTypeIn\x12\x43\n\x13\x63luster_type_not_in\x18\n \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\x10\x63lusterTypeNotIn\"\x9b\x01\n\x15WatchClustersResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12*\n\x07\x63luster\x18\x03 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\xd4\x01\n\x17QueryClusterLogsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x43\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12?\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndTimestamp\"G\n\x18QueryClusterLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries\"\x92\x01\n\x16TailClusterLogsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x43\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\"F\n\x17TailClusterLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries2\x83\x06\n\x0e\x43lusterService\x12P\n\rCreateCluster\x12\x1d.grid.v1.CreateClusterRequest\x1a\x1e.grid.v1.CreateClusterResponse\"\x00\x12G\n\nGetCluster\x12\x1a.grid.v1.GetClusterRequest\x1a\x1b.grid.v1.GetClusterResponse\"\x00\x12M\n\x0cListClusters\x12\x1c.grid.v1.ListClustersRequest\x1a\x1d.grid.v1.ListClustersResponse\"\x00\x12P\n\rUpdateCluster\x12\x1d.grid.v1.UpdateClusterRequest\x1a\x1e.grid.v1.UpdateClusterResponse\"\x00\x12`\n\x13UpdateClusterStatus\x12#.grid.v1.UpdateClusterStatusRequest\x1a$.grid.v1.UpdateClusterStatusResponse\x12P\n\rDeleteCluster\x12\x1d.grid.v1.DeleteClusterRequest\x1a\x1e.grid.v1.DeleteClusterResponse\"\x00\x12P\n\rWatchClusters\x12\x1d.grid.v1.WatchClustersRequest\x1a\x1e.grid.v1.WatchClustersResponse0\x01\x12W\n\x10QueryClusterLogs\x12 .grid.v1.QueryClusterLogsRequest\x1a!.grid.v1.QueryClusterLogsResponse\x12V\n\x0fTailClusterLogs\x12\x1f.grid.v1.TailClusterLogsRequest\x1a .grid.v1.TailClusterLogsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_cluster__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        grid_dot_v1_dot_logs__pb2.DESCRIPTOR,
    ]
)

_CREATECLUSTERREQUEST = _descriptor.Descriptor(
    name='CreateClusterRequest',
    full_name='grid.v1.CreateClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.CreateClusterRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=172,
    serialized_end=238,
)

_CREATECLUSTERRESPONSE = _descriptor.Descriptor(
    name='CreateClusterResponse',
    full_name='grid.v1.CreateClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.CreateClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=240,
    serialized_end=307,
)

_GETCLUSTERREQUEST = _descriptor.Descriptor(
    name='GetClusterRequest',
    full_name='grid.v1.GetClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetClusterRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=309,
    serialized_end=344,
)

_GETCLUSTERRESPONSE = _descriptor.Descriptor(
    name='GetClusterResponse',
    full_name='grid.v1.GetClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.GetClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=346,
    serialized_end=410,
)

_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
    name='ListClustersRequest',
    full_name='grid.v1.ListClustersRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListClustersRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListClustersRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListClustersRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListClustersRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.ListClustersRequest.phase_in',
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.ListClustersRequest.phase_not_in',
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_in',
            full_name='grid.v1.ListClustersRequest.desired_state_in',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_not_in',
            full_name='grid.v1.ListClustersRequest.desired_state_not_in',
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_in',
            full_name='grid.v1.ListClustersRequest.cluster_type_in',
            index=8,
            number=9,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_not_in',
            full_name='grid.v1.ListClustersRequest.cluster_type_not_in',
            index=9,
            number=10,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=413,
    serialized_end=938,
)

_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
    name='ListClustersResponse',
    full_name='grid.v1.ListClustersResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.ListClustersResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListClustersResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListClustersResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=941,
    serialized_end=1089,
)

_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
    name='UpdateClusterRequest',
    full_name='grid.v1.UpdateClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1091,
    serialized_end=1157,
)

_UPDATECLUSTERRESPONSE = _descriptor.Descriptor(
    name='UpdateClusterResponse',
    full_name='grid.v1.UpdateClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1159,
    serialized_end=1226,
)

_UPDATECLUSTERSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateClusterStatusRequest',
    full_name='grid.v1.UpdateClusterStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterStatusRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1228,
    serialized_end=1300,
)

_UPDATECLUSTERSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateClusterStatusResponse',
    full_name='grid.v1.UpdateClusterStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterStatusResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1302,
    serialized_end=1375,
)

_DELETECLUSTERREQUEST = _descriptor.Descriptor(
    name='DeleteClusterRequest',
    full_name='grid.v1.DeleteClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.DeleteClusterRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1377,
    serialized_end=1443,
)

_DELETECLUSTERRESPONSE = _descriptor.Descriptor(
    name='DeleteClusterResponse',
    full_name='grid.v1.DeleteClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.DeleteClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1445,
    serialized_end=1512,
)

_WATCHCLUSTERSREQUEST = _descriptor.Descriptor(
    name='WatchClustersRequest',
    full_name='grid.v1.WatchClustersRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchClustersRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchClustersRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchClustersRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.WatchClustersRequest.phase_in',
            index=3,
            number=5,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.WatchClustersRequest.phase_not_in',
            index=4,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_in',
            full_name='grid.v1.WatchClustersRequest.desired_state_in',
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_not_in',
            full_name='grid.v1.WatchClustersRequest.desired_state_not_in',
            index=6,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_in',
            full_name='grid.v1.WatchClustersRequest.cluster_type_in',
            index=7,
            number=9,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_not_in',
            full_name='grid.v1.WatchClustersRequest.cluster_type_not_in',
            index=8,
            number=10,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1515,
    serialized_end=2002,
)

_WATCHCLUSTERSRESPONSE = _descriptor.Descriptor(
    name='WatchClustersResponse',
    full_name='grid.v1.WatchClustersResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchClustersResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchClustersResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.WatchClustersResponse.cluster',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2005,
    serialized_end=2160,
)

_QUERYCLUSTERLOGSREQUEST = _descriptor.Descriptor(
    name='QueryClusterLogsRequest',
    full_name='grid.v1.QueryClusterLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.QueryClusterLogsRequest.cluster_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.QueryClusterLogsRequest.limit',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.QueryClusterLogsRequest.start_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='end_timestamp',
            full_name='grid.v1.QueryClusterLogsRequest.end_timestamp',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='endTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2163,
    serialized_end=2375,
)

_QUERYCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
    name='QueryClusterLogsResponse',
    full_name='grid.v1.QueryClusterLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='entries',
            full_name='grid.v1.QueryClusterLogsResponse.entries',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='entries',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2377,
    serialized_end=2448,
)

_TAILCLUSTERLOGSREQUEST = _descriptor.Descriptor(
    name='TailClusterLogsRequest',
    full_name='grid.v1.TailClusterLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.TailClusterLogsRequest.cluster_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.TailClusterLogsRequest.limit',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.TailClusterLogsRequest.start_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2451,
    serialized_end=2597,
)

_TAILCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
    name='TailClusterLogsResponse',
    full_name='grid.v1.TailClusterLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='entries',
            full_name='grid.v1.TailClusterLogsResponse.entries',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='entries',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2599,
    serialized_end=2669,
)

_CREATECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_CREATECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_GETCLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_LISTCLUSTERSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['desired_state_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['desired_state_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['cluster_type_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_LISTCLUSTERSREQUEST.fields_by_name['cluster_type_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_LISTCLUSTERSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERSTATUSREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERSTATUSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_DELETECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_DELETECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_WATCHCLUSTERSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['desired_state_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['desired_state_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['cluster_type_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_WATCHCLUSTERSREQUEST.fields_by_name['cluster_type_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_WATCHCLUSTERSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHCLUSTERSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_QUERYCLUSTERLOGSREQUEST.fields_by_name['start_timestamp'
                                        ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYCLUSTERLOGSREQUEST.fields_by_name['end_timestamp'
                                        ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYCLUSTERLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
_TAILCLUSTERLOGSREQUEST.fields_by_name['start_timestamp'
                                       ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAILCLUSTERLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
DESCRIPTOR.message_types_by_name['CreateClusterRequest'] = _CREATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateClusterResponse'] = _CREATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['GetClusterRequest'] = _GETCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['GetClusterResponse'] = _GETCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterResponse'] = _UPDATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterStatusRequest'] = _UPDATECLUSTERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterStatusResponse'] = _UPDATECLUSTERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterResponse'] = _DELETECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['WatchClustersRequest'] = _WATCHCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['WatchClustersResponse'] = _WATCHCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryClusterLogsRequest'] = _QUERYCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['QueryClusterLogsResponse'] = _QUERYCLUSTERLOGSRESPONSE
DESCRIPTOR.message_types_by_name['TailClusterLogsRequest'] = _TAILCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['TailClusterLogsResponse'] = _TAILCLUSTERLOGSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateClusterRequest = _reflection.GeneratedProtocolMessageType(
    'CreateClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATECLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateClusterRequest)
    }
)
_sym_db.RegisterMessage(CreateClusterRequest)

CreateClusterResponse = _reflection.GeneratedProtocolMessageType(
    'CreateClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATECLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateClusterResponse)
    }
)
_sym_db.RegisterMessage(CreateClusterResponse)

GetClusterRequest = _reflection.GeneratedProtocolMessageType(
    'GetClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETCLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetClusterRequest)
    }
)
_sym_db.RegisterMessage(GetClusterRequest)

GetClusterResponse = _reflection.GeneratedProtocolMessageType(
    'GetClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETCLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetClusterResponse)
    }
)
_sym_db.RegisterMessage(GetClusterResponse)

ListClustersRequest = _reflection.GeneratedProtocolMessageType(
    'ListClustersRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTCLUSTERSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListClustersRequest)
    }
)
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType(
    'ListClustersResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTCLUSTERSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListClustersResponse)
    }
)
_sym_db.RegisterMessage(ListClustersResponse)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterRequest)
    }
)
_sym_db.RegisterMessage(UpdateClusterRequest)

UpdateClusterResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterResponse)
    }
)
_sym_db.RegisterMessage(UpdateClusterResponse)

UpdateClusterStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERSTATUSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateClusterStatusRequest)

UpdateClusterStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERSTATUSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateClusterStatusResponse)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETECLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteClusterRequest)
    }
)
_sym_db.RegisterMessage(DeleteClusterRequest)

DeleteClusterResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETECLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteClusterResponse)
    }
)
_sym_db.RegisterMessage(DeleteClusterResponse)

WatchClustersRequest = _reflection.GeneratedProtocolMessageType(
    'WatchClustersRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHCLUSTERSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchClustersRequest)
    }
)
_sym_db.RegisterMessage(WatchClustersRequest)

WatchClustersResponse = _reflection.GeneratedProtocolMessageType(
    'WatchClustersResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHCLUSTERSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchClustersResponse)
    }
)
_sym_db.RegisterMessage(WatchClustersResponse)

QueryClusterLogsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryClusterLogsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _QUERYCLUSTERLOGSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.QueryClusterLogsRequest)
    }
)
_sym_db.RegisterMessage(QueryClusterLogsRequest)

QueryClusterLogsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryClusterLogsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _QUERYCLUSTERLOGSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.QueryClusterLogsResponse)
    }
)
_sym_db.RegisterMessage(QueryClusterLogsResponse)

TailClusterLogsRequest = _reflection.GeneratedProtocolMessageType(
    'TailClusterLogsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TAILCLUSTERLOGSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TailClusterLogsRequest)
    }
)
_sym_db.RegisterMessage(TailClusterLogsRequest)

TailClusterLogsResponse = _reflection.GeneratedProtocolMessageType(
    'TailClusterLogsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TAILCLUSTERLOGSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TailClusterLogsResponse)
    }
)
_sym_db.RegisterMessage(TailClusterLogsResponse)

DESCRIPTOR._options = None

_CLUSTERSERVICE = _descriptor.ServiceDescriptor(
    name='ClusterService',
    full_name='grid.v1.ClusterService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2672,
    serialized_end=3443,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateCluster',
            full_name='grid.v1.ClusterService.CreateCluster',
            index=0,
            containing_service=None,
            input_type=_CREATECLUSTERREQUEST,
            output_type=_CREATECLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetCluster',
            full_name='grid.v1.ClusterService.GetCluster',
            index=1,
            containing_service=None,
            input_type=_GETCLUSTERREQUEST,
            output_type=_GETCLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListClusters',
            full_name='grid.v1.ClusterService.ListClusters',
            index=2,
            containing_service=None,
            input_type=_LISTCLUSTERSREQUEST,
            output_type=_LISTCLUSTERSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateCluster',
            full_name='grid.v1.ClusterService.UpdateCluster',
            index=3,
            containing_service=None,
            input_type=_UPDATECLUSTERREQUEST,
            output_type=_UPDATECLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateClusterStatus',
            full_name='grid.v1.ClusterService.UpdateClusterStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATECLUSTERSTATUSREQUEST,
            output_type=_UPDATECLUSTERSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteCluster',
            full_name='grid.v1.ClusterService.DeleteCluster',
            index=5,
            containing_service=None,
            input_type=_DELETECLUSTERREQUEST,
            output_type=_DELETECLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchClusters',
            full_name='grid.v1.ClusterService.WatchClusters',
            index=6,
            containing_service=None,
            input_type=_WATCHCLUSTERSREQUEST,
            output_type=_WATCHCLUSTERSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='QueryClusterLogs',
            full_name='grid.v1.ClusterService.QueryClusterLogs',
            index=7,
            containing_service=None,
            input_type=_QUERYCLUSTERLOGSREQUEST,
            output_type=_QUERYCLUSTERLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='TailClusterLogs',
            full_name='grid.v1.ClusterService.TailClusterLogs',
            index=8,
            containing_service=None,
            input_type=_TAILCLUSTERLOGSREQUEST,
            output_type=_TAILCLUSTERLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_CLUSTERSERVICE)

DESCRIPTOR.services_by_name['ClusterService'] = _CLUSTERSERVICE

# @@protoc_insertion_point(module_scope)
