# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/suspicious_activity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/suspicious_activity.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n!grid/v1/suspicious_activity.proto\x12\x07grid.v1\"\xfc\x01\n\x1fReportSuspiciousActivityRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06reason\x18\x04 \x01(\tR\x06reason\x12\x18\n\x07\x64\x65tails\x18\x05 \x01(\tR\x07\x64\x65tails\x12:\n\rresource_type\x18\x06 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x1f\n\x0bresource_id\x18\x07 \x01(\tR\nresourceId\"\"\n ReportSuspiciousActivityResponse*f\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15RESOURCE_TYPE_SESSION\x10\x01\x12\x1c\n\x18RESOURCE_TYPE_EXPERIMENT\x10\x02\x32\x8c\x01\n\x19SuspiciousActivityService\x12o\n\x18ReportSuspiciousActivity\x12(.grid.v1.ReportSuspiciousActivityRequest\x1a).grid.v1.ReportSuspiciousActivityResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_RESOURCETYPE = _descriptor.EnumDescriptor(
    name='ResourceType',
    full_name='grid.v1.ResourceType',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='RESOURCE_TYPE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RESOURCE_TYPE_SESSION',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RESOURCE_TYPE_EXPERIMENT',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=337,
    serialized_end=439,
)
_sym_db.RegisterEnumDescriptor(_RESOURCETYPE)

ResourceType = enum_type_wrapper.EnumTypeWrapper(_RESOURCETYPE)
RESOURCE_TYPE_UNSPECIFIED = 0
RESOURCE_TYPE_SESSION = 1
RESOURCE_TYPE_EXPERIMENT = 2

_REPORTSUSPICIOUSACTIVITYREQUEST = _descriptor.Descriptor(
    name='ReportSuspiciousActivityRequest',
    full_name='grid.v1.ReportSuspiciousActivityRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ReportSuspiciousActivityRequest.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ReportSuspiciousActivityRequest.cluster_id',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.ReportSuspiciousActivityRequest.type',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='reason',
            full_name='grid.v1.ReportSuspiciousActivityRequest.reason',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='reason',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='details',
            full_name='grid.v1.ReportSuspiciousActivityRequest.details',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='details',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_type',
            full_name='grid.v1.ReportSuspiciousActivityRequest.resource_type',
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceType',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_id',
            full_name='grid.v1.ReportSuspiciousActivityRequest.resource_id',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=47,
    serialized_end=299,
)

_REPORTSUSPICIOUSACTIVITYRESPONSE = _descriptor.Descriptor(
    name='ReportSuspiciousActivityResponse',
    full_name='grid.v1.ReportSuspiciousActivityResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=301,
    serialized_end=335,
)

_REPORTSUSPICIOUSACTIVITYREQUEST.fields_by_name['resource_type'].enum_type = _RESOURCETYPE
DESCRIPTOR.message_types_by_name['ReportSuspiciousActivityRequest'] = _REPORTSUSPICIOUSACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['ReportSuspiciousActivityResponse'] = _REPORTSUSPICIOUSACTIVITYRESPONSE
DESCRIPTOR.enum_types_by_name['ResourceType'] = _RESOURCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReportSuspiciousActivityRequest = _reflection.GeneratedProtocolMessageType(
    'ReportSuspiciousActivityRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _REPORTSUSPICIOUSACTIVITYREQUEST,
        '__module__': 'grid.v1.suspicious_activity_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ReportSuspiciousActivityRequest)
    }
)
_sym_db.RegisterMessage(ReportSuspiciousActivityRequest)

ReportSuspiciousActivityResponse = _reflection.GeneratedProtocolMessageType(
    'ReportSuspiciousActivityResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _REPORTSUSPICIOUSACTIVITYRESPONSE,
        '__module__': 'grid.v1.suspicious_activity_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ReportSuspiciousActivityResponse)
    }
)
_sym_db.RegisterMessage(ReportSuspiciousActivityResponse)

DESCRIPTOR._options = None

_SUSPICIOUSACTIVITYSERVICE = _descriptor.ServiceDescriptor(
    name='SuspiciousActivityService',
    full_name='grid.v1.SuspiciousActivityService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=442,
    serialized_end=582,
    methods=[
        _descriptor.MethodDescriptor(
            name='ReportSuspiciousActivity',
            full_name='grid.v1.SuspiciousActivityService.ReportSuspiciousActivity',
            index=0,
            containing_service=None,
            input_type=_REPORTSUSPICIOUSACTIVITYREQUEST,
            output_type=_REPORTSUSPICIOUSACTIVITYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_SUSPICIOUSACTIVITYSERVICE)

DESCRIPTOR.services_by_name['SuspiciousActivityService'] = _SUSPICIOUSACTIVITYSERVICE

# @@protoc_insertion_point(module_scope)
