# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import user_pb2 as grid_dot_v1_dot_user__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/user_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1agrid/v1/user_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x12grid/v1/user.proto\"6\n\x11\x43reateUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"7\n\x12\x43reateUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\" \n\x0eGetUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"4\n\x0fGetUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"z\n\x10ListUsersRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\"\x88\x01\n\x11ListUsersResponse\x12!\n\x04user\x18\x01 \x03(\x0b\x32\r.grid.v1.UserR\x04user\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"6\n\x11UpdateUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"7\n\x12UpdateUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"<\n\x17UpdateUserStatusRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"=\n\x18UpdateUserStatusResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"6\n\x11\x44\x65leteUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"7\n\x12\x44\x65leteUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"T\n\x11WatchUsersRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\"\x8f\x01\n\x12WatchUsersResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12!\n\x04user\x18\x03 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"3\n\x18StopUserWorkloadsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\x1b\n\x19StopUserWorkloadsResponse2\xec\x04\n\x0bUserService\x12G\n\nCreateUser\x12\x1a.grid.v1.CreateUserRequest\x1a\x1b.grid.v1.CreateUserResponse\"\x00\x12>\n\x07GetUser\x12\x17.grid.v1.GetUserRequest\x1a\x18.grid.v1.GetUserResponse\"\x00\x12\x44\n\tListUsers\x12\x19.grid.v1.ListUsersRequest\x1a\x1a.grid.v1.ListUsersResponse\"\x00\x12G\n\nUpdateUser\x12\x1a.grid.v1.UpdateUserRequest\x1a\x1b.grid.v1.UpdateUserResponse\"\x00\x12W\n\x10UpdateUserStatus\x12 .grid.v1.UpdateUserStatusRequest\x1a!.grid.v1.UpdateUserStatusResponse\x12G\n\nDeleteUser\x12\x1a.grid.v1.DeleteUserRequest\x1a\x1b.grid.v1.DeleteUserResponse\"\x00\x12G\n\nWatchUsers\x12\x1a.grid.v1.WatchUsersRequest\x1a\x1b.grid.v1.WatchUsersResponse0\x01\x12Z\n\x11StopUserWorkloads\x12!.grid.v1.StopUserWorkloadsRequest\x1a\".grid.v1.StopUserWorkloadsResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_user__pb2.DESCRIPTOR,
    ]
)

_CREATEUSERREQUEST = _descriptor.Descriptor(
    name='CreateUserRequest',
    full_name='grid.v1.CreateUserRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.CreateUserRequest.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=113,
    serialized_end=167,
)

_CREATEUSERRESPONSE = _descriptor.Descriptor(
    name='CreateUserResponse',
    full_name='grid.v1.CreateUserResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.CreateUserResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=169,
    serialized_end=224,
)

_GETUSERREQUEST = _descriptor.Descriptor(
    name='GetUserRequest',
    full_name='grid.v1.GetUserRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetUserRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=226,
    serialized_end=258,
)

_GETUSERRESPONSE = _descriptor.Descriptor(
    name='GetUserResponse',
    full_name='grid.v1.GetUserResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.GetUserResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=260,
    serialized_end=312,
)

_LISTUSERSREQUEST = _descriptor.Descriptor(
    name='ListUsersRequest',
    full_name='grid.v1.ListUsersRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListUsersRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListUsersRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListUsersRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=314,
    serialized_end=436,
)

_LISTUSERSRESPONSE = _descriptor.Descriptor(
    name='ListUsersResponse',
    full_name='grid.v1.ListUsersResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.ListUsersResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListUsersResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListUsersResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=439,
    serialized_end=575,
)

_UPDATEUSERREQUEST = _descriptor.Descriptor(
    name='UpdateUserRequest',
    full_name='grid.v1.UpdateUserRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.UpdateUserRequest.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=577,
    serialized_end=631,
)

_UPDATEUSERRESPONSE = _descriptor.Descriptor(
    name='UpdateUserResponse',
    full_name='grid.v1.UpdateUserResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.UpdateUserResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=633,
    serialized_end=688,
)

_UPDATEUSERSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateUserStatusRequest',
    full_name='grid.v1.UpdateUserStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.UpdateUserStatusRequest.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=690,
    serialized_end=750,
)

_UPDATEUSERSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateUserStatusResponse',
    full_name='grid.v1.UpdateUserStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.UpdateUserStatusResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=752,
    serialized_end=813,
)

_DELETEUSERREQUEST = _descriptor.Descriptor(
    name='DeleteUserRequest',
    full_name='grid.v1.DeleteUserRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.DeleteUserRequest.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=815,
    serialized_end=869,
)

_DELETEUSERRESPONSE = _descriptor.Descriptor(
    name='DeleteUserResponse',
    full_name='grid.v1.DeleteUserResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.DeleteUserResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=871,
    serialized_end=926,
)

_WATCHUSERSREQUEST = _descriptor.Descriptor(
    name='WatchUsersRequest',
    full_name='grid.v1.WatchUsersRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchUsersRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchUsersRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=928,
    serialized_end=1012,
)

_WATCHUSERSRESPONSE = _descriptor.Descriptor(
    name='WatchUsersResponse',
    full_name='grid.v1.WatchUsersResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchUsersResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchUsersResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.WatchUsersResponse.user',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1015,
    serialized_end=1158,
)

_STOPUSERWORKLOADSREQUEST = _descriptor.Descriptor(
    name='StopUserWorkloadsRequest',
    full_name='grid.v1.StopUserWorkloadsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.StopUserWorkloadsRequest.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1160,
    serialized_end=1211,
)

_STOPUSERWORKLOADSRESPONSE = _descriptor.Descriptor(
    name='StopUserWorkloadsResponse',
    full_name='grid.v1.StopUserWorkloadsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1213,
    serialized_end=1240,
)

_CREATEUSERREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_CREATEUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_GETUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_LISTUSERSRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERSTATUSREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERSTATUSRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_DELETEUSERREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_DELETEUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_WATCHUSERSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHUSERSRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateUserResponse'] = _CREATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['GetUserRequest'] = _GETUSERREQUEST
DESCRIPTOR.message_types_by_name['GetUserResponse'] = _GETUSERRESPONSE
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['ListUsersResponse'] = _LISTUSERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserRequest'] = _UPDATEUSERREQUEST
DESCRIPTOR.message_types_by_name['UpdateUserResponse'] = _UPDATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserStatusRequest'] = _UPDATEUSERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateUserStatusResponse'] = _UPDATEUSERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteUserRequest'] = _DELETEUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteUserResponse'] = _DELETEUSERRESPONSE
DESCRIPTOR.message_types_by_name['WatchUsersRequest'] = _WATCHUSERSREQUEST
DESCRIPTOR.message_types_by_name['WatchUsersResponse'] = _WATCHUSERSRESPONSE
DESCRIPTOR.message_types_by_name['StopUserWorkloadsRequest'] = _STOPUSERWORKLOADSREQUEST
DESCRIPTOR.message_types_by_name['StopUserWorkloadsResponse'] = _STOPUSERWORKLOADSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateUserRequest = _reflection.GeneratedProtocolMessageType(
    'CreateUserRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATEUSERREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateUserRequest)
    }
)
_sym_db.RegisterMessage(CreateUserRequest)

CreateUserResponse = _reflection.GeneratedProtocolMessageType(
    'CreateUserResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATEUSERRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateUserResponse)
    }
)
_sym_db.RegisterMessage(CreateUserResponse)

GetUserRequest = _reflection.GeneratedProtocolMessageType(
    'GetUserRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETUSERREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetUserRequest)
    }
)
_sym_db.RegisterMessage(GetUserRequest)

GetUserResponse = _reflection.GeneratedProtocolMessageType(
    'GetUserResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETUSERRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetUserResponse)
    }
)
_sym_db.RegisterMessage(GetUserResponse)

ListUsersRequest = _reflection.GeneratedProtocolMessageType(
    'ListUsersRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTUSERSREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListUsersRequest)
    }
)
_sym_db.RegisterMessage(ListUsersRequest)

ListUsersResponse = _reflection.GeneratedProtocolMessageType(
    'ListUsersResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTUSERSRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListUsersResponse)
    }
)
_sym_db.RegisterMessage(ListUsersResponse)

UpdateUserRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateUserRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEUSERREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserRequest)
    }
)
_sym_db.RegisterMessage(UpdateUserRequest)

UpdateUserResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateUserResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEUSERRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserResponse)
    }
)
_sym_db.RegisterMessage(UpdateUserResponse)

UpdateUserStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateUserStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEUSERSTATUSREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateUserStatusRequest)

UpdateUserStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateUserStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEUSERSTATUSRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateUserStatusResponse)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteUserRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETEUSERREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteUserRequest)
    }
)
_sym_db.RegisterMessage(DeleteUserRequest)

DeleteUserResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteUserResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETEUSERRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteUserResponse)
    }
)
_sym_db.RegisterMessage(DeleteUserResponse)

WatchUsersRequest = _reflection.GeneratedProtocolMessageType(
    'WatchUsersRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHUSERSREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchUsersRequest)
    }
)
_sym_db.RegisterMessage(WatchUsersRequest)

WatchUsersResponse = _reflection.GeneratedProtocolMessageType(
    'WatchUsersResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHUSERSRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchUsersResponse)
    }
)
_sym_db.RegisterMessage(WatchUsersResponse)

StopUserWorkloadsRequest = _reflection.GeneratedProtocolMessageType(
    'StopUserWorkloadsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _STOPUSERWORKLOADSREQUEST,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.StopUserWorkloadsRequest)
    }
)
_sym_db.RegisterMessage(StopUserWorkloadsRequest)

StopUserWorkloadsResponse = _reflection.GeneratedProtocolMessageType(
    'StopUserWorkloadsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _STOPUSERWORKLOADSRESPONSE,
        '__module__': 'grid.v1.user_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.StopUserWorkloadsResponse)
    }
)
_sym_db.RegisterMessage(StopUserWorkloadsResponse)

DESCRIPTOR._options = None

_USERSERVICE = _descriptor.ServiceDescriptor(
    name='UserService',
    full_name='grid.v1.UserService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1243,
    serialized_end=1863,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateUser',
            full_name='grid.v1.UserService.CreateUser',
            index=0,
            containing_service=None,
            input_type=_CREATEUSERREQUEST,
            output_type=_CREATEUSERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetUser',
            full_name='grid.v1.UserService.GetUser',
            index=1,
            containing_service=None,
            input_type=_GETUSERREQUEST,
            output_type=_GETUSERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListUsers',
            full_name='grid.v1.UserService.ListUsers',
            index=2,
            containing_service=None,
            input_type=_LISTUSERSREQUEST,
            output_type=_LISTUSERSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateUser',
            full_name='grid.v1.UserService.UpdateUser',
            index=3,
            containing_service=None,
            input_type=_UPDATEUSERREQUEST,
            output_type=_UPDATEUSERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateUserStatus',
            full_name='grid.v1.UserService.UpdateUserStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATEUSERSTATUSREQUEST,
            output_type=_UPDATEUSERSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteUser',
            full_name='grid.v1.UserService.DeleteUser',
            index=5,
            containing_service=None,
            input_type=_DELETEUSERREQUEST,
            output_type=_DELETEUSERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchUsers',
            full_name='grid.v1.UserService.WatchUsers',
            index=6,
            containing_service=None,
            input_type=_WATCHUSERSREQUEST,
            output_type=_WATCHUSERSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='StopUserWorkloads',
            full_name='grid.v1.UserService.StopUserWorkloads',
            index=7,
            containing_service=None,
            input_type=_STOPUSERWORKLOADSREQUEST,
            output_type=_STOPUSERWORKLOADSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_USERSERVICE)

DESCRIPTOR.services_by_name['UserService'] = _USERSERVICE

# @@protoc_insertion_point(module_scope)
