# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import sshpublickey_service_pb2 as grid_dot_v1_dot_sshpublickey__service__pb2


class SSHPublicKeyServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateSSHPublicKey = channel.unary_unary(
            '/grid.v1.SSHPublicKeyService/CreateSSHPublicKey',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyResponse.FromString,
        )
        self.GetSSHPublicKey = channel.unary_unary(
            '/grid.v1.SSHPublicKeyService/GetSSHPublicKey',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyResponse.FromString,
        )
        self.ListSSHPublicKeys = channel.unary_unary(
            '/grid.v1.SSHPublicKeyService/ListSSHPublicKeys',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysResponse.FromString,
        )
        self.UpdateSSHPublicKey = channel.unary_unary(
            '/grid.v1.SSHPublicKeyService/UpdateSSHPublicKey',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyResponse.FromString,
        )
        self.UpdateSSHPublicKeyStatus = channel.unary_unary(
            '/grid.v1.SSHPublicKeyService/UpdateSSHPublicKeyStatus',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusRequest.
            SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusResponse.
            FromString,
        )
        self.DeleteSSHPublicKey = channel.unary_unary(
            '/grid.v1.SSHPublicKeyService/DeleteSSHPublicKey',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyResponse.FromString,
        )
        self.WatchSSHPublicKeys = channel.unary_stream(
            '/grid.v1.SSHPublicKeyService/WatchSSHPublicKeys',
            request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysResponse.FromString,
        )


class SSHPublicKeyServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateSSHPublicKey(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSSHPublicKey(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSSHPublicKeys(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSSHPublicKey(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSSHPublicKeyStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSSHPublicKey(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchSSHPublicKeys(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SSHPublicKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateSSHPublicKey':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateSSHPublicKey,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyResponse.SerializeToString,
        ),
        'GetSSHPublicKey':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetSSHPublicKey,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyResponse.SerializeToString,
        ),
        'ListSSHPublicKeys':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListSSHPublicKeys,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysResponse.SerializeToString,
        ),
        'UpdateSSHPublicKey':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateSSHPublicKey,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyResponse.SerializeToString,
        ),
        'UpdateSSHPublicKeyStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateSSHPublicKeyStatus,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusResponse.
            SerializeToString,
        ),
        'DeleteSSHPublicKey':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteSSHPublicKey,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyResponse.SerializeToString,
        ),
        'WatchSSHPublicKeys':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchSSHPublicKeys,
            request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysRequest.FromString,
            response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.SSHPublicKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
