# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/resource.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x16grid/v1/resource.proto\x12\x07grid.v1\"\xbd\x01\n\tResources\x12\x10\n\x03\x63pu\x18\x01 \x01(\x04R\x03\x63pu\x12\x10\n\x03gpu\x18\x02 \x01(\x04R\x03gpu\x12\x1d\n\nstorage_gb\x18\x03 \x01(\x04R\tstorageGb\x12\x33\n\x05\x65xtra\x18\x04 \x03(\x0b\x32\x1d.grid.v1.Resources.ExtraEntryR\x05\x65xtra\x1a\x38\n\nExtraEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_RESOURCES_EXTRAENTRY = _descriptor.Descriptor(
    name='ExtraEntry',
    full_name='grid.v1.Resources.ExtraEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='grid.v1.Resources.ExtraEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='key',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='grid.v1.Resources.ExtraEntry.value',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='value',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=169,
    serialized_end=225,
)

_RESOURCES = _descriptor.Descriptor(
    name='Resources',
    full_name='grid.v1.Resources',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cpu',
            full_name='grid.v1.Resources.cpu',
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cpu',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='gpu',
            full_name='grid.v1.Resources.gpu',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='gpu',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='storage_gb',
            full_name='grid.v1.Resources.storage_gb',
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='storageGb',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='extra',
            full_name='grid.v1.Resources.extra',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='extra',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOURCES_EXTRAENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=36,
    serialized_end=225,
)

_RESOURCES_EXTRAENTRY.containing_type = _RESOURCES
_RESOURCES.fields_by_name['extra'].message_type = _RESOURCES_EXTRAENTRY
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resources = _reflection.GeneratedProtocolMessageType(
    'Resources',
    (_message.Message, ),
    {
        'ExtraEntry':
        _reflection.GeneratedProtocolMessageType(
            'ExtraEntry',
            (_message.Message, ),
            {
                'DESCRIPTOR': _RESOURCES_EXTRAENTRY,
                '__module__': 'grid.v1.resource_pb2'
                # @@protoc_insertion_point(class_scope:grid.v1.Resources.ExtraEntry)
            }
        ),
        'DESCRIPTOR':
        _RESOURCES,
        '__module__':
        'grid.v1.resource_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Resources)
    }
)
_sym_db.RegisterMessage(Resources)
_sym_db.RegisterMessage(Resources.ExtraEntry)

DESCRIPTOR._options = None
_RESOURCES_EXTRAENTRY._options = None
# @@protoc_insertion_point(module_scope)
