# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/experiment_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import logs_pb2 as grid_dot_v1_dot_logs__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/experiment_details.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n grid/v1/experiment_details.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12grid/v1/logs.proto\"r\n\x0eGetLogsRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12%\n\x0e\x63ontinue_token\x18\x03 \x01(\tR\rcontinueToken\"e\n\x0fGetLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\"t\n\x10WatchLogsRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12%\n\x0e\x63ontinue_token\x18\x03 \x01(\tR\rcontinueToken\"g\n\x11WatchLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\"\x98\x02\n\x08\x41rtifact\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\nsize_bytes\x18\x02 \x01(\x03R\tsizeBytes\x12;\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12?\n\rmodified_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cmodifiedTime\x12#\n\rcache_control\x18\x05 \x01(\tR\x0c\x63\x61\x63heControl\x12\x13\n\x05\x65_tag\x18\x06 \x01(\tR\x04\x65Tag\x12!\n\x0c\x64ownload_url\x18\x07 \x01(\tR\x0b\x64ownloadUrl\"x\n\x14ListArtifactsRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12%\n\x0e\x63ontinue_token\x18\x03 \x01(\tR\rcontinueToken\"H\n\x15ListArtifactsResponse\x12/\n\tartifacts\x18\x01 \x03(\x0b\x32\x11.grid.v1.ArtifactR\tartifacts\"R\n\x15WatchArtifactsRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\"I\n\x16WatchArtifactsResponse\x12/\n\tartifacts\x18\x01 \x03(\x0b\x32\x11.grid.v1.ArtifactR\tartifacts\"\xb2\x01\n\x07Metrics\x12\x16\n\x06values\x18\x01 \x03(\x01R\x06values\x12\x14\n\x05steps\x18\x02 \x03(\x03R\x05steps\x12\x1f\n\x0bstart_index\x18\x03 \x01(\x03R\nstartIndex\x12\x1b\n\tend_index\x18\x04 \x01(\x03R\x08\x65ndIndex\x12\x16\n\x06metric\x18\x05 \x01(\tR\x06metric\x12#\n\rexperiment_id\x18\x06 \x01(\tR\x0c\x65xperimentId\"\x98\x01\n\x1bGetExperimentMetricsRequest\x12#\n\rexperiment_id\x18\x01 \x03(\tR\x0c\x65xperimentId\x12\x16\n\x06metric\x18\x02 \x03(\tR\x06metric\x12\x1f\n\x0bstart_index\x18\x03 \x01(\x03R\nstartIndex\x12\x1b\n\tend_index\x18\x04 \x01(\x03R\x08\x65ndIndex\"J\n\x1cGetExperimentMetricsResponse\x12*\n\x07metrics\x18\x01 \x03(\x0b\x32\x10.grid.v1.MetricsR\x07metrics\"B\n\x1bListAvailableMetricsRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\"8\n\x1cListAvailableMetricsResponse\x12\x18\n\x07metrics\x18\x01 \x03(\tR\x07metrics\"}\n\x1dWatchExperimentMetricsRequest\x12#\n\rexperiment_id\x18\x01 \x03(\tR\x0c\x65xperimentId\x12\x16\n\x06metric\x18\x02 \x03(\tR\x06metric\x12\x1f\n\x0bstart_index\x18\x03 \x01(\x03R\nstartIndex\"L\n\x1eWatchExperimentMetricsResponse\x12*\n\x07metrics\x18\x01 \x03(\x0b\x32\x10.grid.v1.MetricsR\x07metrics\"\xc5\x01\n\x18GetExperimentCostRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12?\n\rend_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndTimestamp\"/\n\x19GetExperimentCostResponse\x12\x12\n\x04\x63ost\x18\x01 \x01(\x01R\x04\x63ost\"\xbc\x01\n\x15GetSessionCostRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12?\n\rend_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndTimestamp\",\n\x16GetSessionCostResponse\x12\x12\n\x04\x63ost\x18\x01 \x01(\x01R\x04\x63ost2\xaf\x06\n\x18\x45xperimentDetailsService\x12<\n\x07GetLogs\x12\x17.grid.v1.GetLogsRequest\x1a\x18.grid.v1.GetLogsResponse\x12\x44\n\tWatchLogs\x12\x19.grid.v1.WatchLogsRequest\x1a\x1a.grid.v1.WatchLogsResponse0\x01\x12N\n\rListArtifacts\x12\x1d.grid.v1.ListArtifactsRequest\x1a\x1e.grid.v1.ListArtifactsResponse\x12S\n\x0eWatchArtifacts\x12\x1e.grid.v1.WatchArtifactsRequest\x1a\x1f.grid.v1.WatchArtifactsResponse0\x01\x12\x65\n\x14GetExperimentMetrics\x12$.grid.v1.GetExperimentMetricsRequest\x1a%.grid.v1.GetExperimentMetricsResponse\"\x00\x12\x65\n\x14ListAvailableMetrics\x12$.grid.v1.ListAvailableMetricsRequest\x1a%.grid.v1.ListAvailableMetricsResponse\"\x00\x12m\n\x16WatchExperimentMetrics\x12&.grid.v1.WatchExperimentMetricsRequest\x1a\'.grid.v1.WatchExperimentMetricsResponse\"\x00\x30\x01\x12Z\n\x11GetExperimentCost\x12!.grid.v1.GetExperimentCostRequest\x1a\".grid.v1.GetExperimentCostResponse\x12Q\n\x0eGetSessionCost\x12\x1e.grid.v1.GetSessionCostRequest\x1a\x1f.grid.v1.GetSessionCostResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        grid_dot_v1_dot_logs__pb2.DESCRIPTOR,
    ]
)

_GETLOGSREQUEST = _descriptor.Descriptor(
    name='GetLogsRequest',
    full_name='grid.v1.GetLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.GetLogsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.GetLogsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.GetLogsRequest.continue_token',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=122,
    serialized_end=236,
)

_GETLOGSRESPONSE = _descriptor.Descriptor(
    name='GetLogsResponse',
    full_name='grid.v1.GetLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='entries',
            full_name='grid.v1.GetLogsResponse.entries',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='entries',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.GetLogsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=238,
    serialized_end=339,
)

_WATCHLOGSREQUEST = _descriptor.Descriptor(
    name='WatchLogsRequest',
    full_name='grid.v1.WatchLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.WatchLogsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchLogsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.WatchLogsRequest.continue_token',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=341,
    serialized_end=457,
)

_WATCHLOGSRESPONSE = _descriptor.Descriptor(
    name='WatchLogsResponse',
    full_name='grid.v1.WatchLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='entries',
            full_name='grid.v1.WatchLogsResponse.entries',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='entries',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.WatchLogsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=459,
    serialized_end=562,
)

_ARTIFACT = _descriptor.Descriptor(
    name='Artifact',
    full_name='grid.v1.Artifact',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='name',
            full_name='grid.v1.Artifact.name',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='name',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='size_bytes',
            full_name='grid.v1.Artifact.size_bytes',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sizeBytes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='create_time',
            full_name='grid.v1.Artifact.create_time',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='createTime',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='modified_time',
            full_name='grid.v1.Artifact.modified_time',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='modifiedTime',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cache_control',
            full_name='grid.v1.Artifact.cache_control',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cacheControl',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='e_tag',
            full_name='grid.v1.Artifact.e_tag',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='eTag',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='download_url',
            full_name='grid.v1.Artifact.download_url',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='downloadUrl',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=565,
    serialized_end=845,
)

_LISTARTIFACTSREQUEST = _descriptor.Descriptor(
    name='ListArtifactsRequest',
    full_name='grid.v1.ListArtifactsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.ListArtifactsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListArtifactsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListArtifactsRequest.continue_token',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=847,
    serialized_end=967,
)

_LISTARTIFACTSRESPONSE = _descriptor.Descriptor(
    name='ListArtifactsResponse',
    full_name='grid.v1.ListArtifactsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='artifacts',
            full_name='grid.v1.ListArtifactsResponse.artifacts',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='artifacts',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=969,
    serialized_end=1041,
)

_WATCHARTIFACTSREQUEST = _descriptor.Descriptor(
    name='WatchArtifactsRequest',
    full_name='grid.v1.WatchArtifactsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.WatchArtifactsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchArtifactsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1043,
    serialized_end=1125,
)

_WATCHARTIFACTSRESPONSE = _descriptor.Descriptor(
    name='WatchArtifactsResponse',
    full_name='grid.v1.WatchArtifactsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='artifacts',
            full_name='grid.v1.WatchArtifactsResponse.artifacts',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='artifacts',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1127,
    serialized_end=1200,
)

_METRICS = _descriptor.Descriptor(
    name='Metrics',
    full_name='grid.v1.Metrics',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='values',
            full_name='grid.v1.Metrics.values',
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='values',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='steps',
            full_name='grid.v1.Metrics.steps',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='steps',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_index',
            full_name='grid.v1.Metrics.start_index',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startIndex',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='end_index',
            full_name='grid.v1.Metrics.end_index',
            index=3,
            number=4,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='endIndex',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='metric',
            full_name='grid.v1.Metrics.metric',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metric',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.Metrics.experiment_id',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1203,
    serialized_end=1381,
)

_GETEXPERIMENTMETRICSREQUEST = _descriptor.Descriptor(
    name='GetExperimentMetricsRequest',
    full_name='grid.v1.GetExperimentMetricsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.GetExperimentMetricsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='metric',
            full_name='grid.v1.GetExperimentMetricsRequest.metric',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metric',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_index',
            full_name='grid.v1.GetExperimentMetricsRequest.start_index',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startIndex',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='end_index',
            full_name='grid.v1.GetExperimentMetricsRequest.end_index',
            index=3,
            number=4,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='endIndex',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1384,
    serialized_end=1536,
)

_GETEXPERIMENTMETRICSRESPONSE = _descriptor.Descriptor(
    name='GetExperimentMetricsResponse',
    full_name='grid.v1.GetExperimentMetricsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metrics',
            full_name='grid.v1.GetExperimentMetricsResponse.metrics',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metrics',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1538,
    serialized_end=1612,
)

_LISTAVAILABLEMETRICSREQUEST = _descriptor.Descriptor(
    name='ListAvailableMetricsRequest',
    full_name='grid.v1.ListAvailableMetricsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.ListAvailableMetricsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1614,
    serialized_end=1680,
)

_LISTAVAILABLEMETRICSRESPONSE = _descriptor.Descriptor(
    name='ListAvailableMetricsResponse',
    full_name='grid.v1.ListAvailableMetricsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metrics',
            full_name='grid.v1.ListAvailableMetricsResponse.metrics',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metrics',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1682,
    serialized_end=1738,
)

_WATCHEXPERIMENTMETRICSREQUEST = _descriptor.Descriptor(
    name='WatchExperimentMetricsRequest',
    full_name='grid.v1.WatchExperimentMetricsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.WatchExperimentMetricsRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='metric',
            full_name='grid.v1.WatchExperimentMetricsRequest.metric',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metric',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_index',
            full_name='grid.v1.WatchExperimentMetricsRequest.start_index',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startIndex',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1740,
    serialized_end=1865,
)

_WATCHEXPERIMENTMETRICSRESPONSE = _descriptor.Descriptor(
    name='WatchExperimentMetricsResponse',
    full_name='grid.v1.WatchExperimentMetricsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metrics',
            full_name='grid.v1.WatchExperimentMetricsResponse.metrics',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metrics',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1867,
    serialized_end=1943,
)

_GETEXPERIMENTCOSTREQUEST = _descriptor.Descriptor(
    name='GetExperimentCostRequest',
    full_name='grid.v1.GetExperimentCostRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.GetExperimentCostRequest.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.GetExperimentCostRequest.start_timestamp',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='end_timestamp',
            full_name='grid.v1.GetExperimentCostRequest.end_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='endTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1946,
    serialized_end=2143,
)

_GETEXPERIMENTCOSTRESPONSE = _descriptor.Descriptor(
    name='GetExperimentCostResponse',
    full_name='grid.v1.GetExperimentCostResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cost',
            full_name='grid.v1.GetExperimentCostResponse.cost',
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cost',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2145,
    serialized_end=2192,
)

_GETSESSIONCOSTREQUEST = _descriptor.Descriptor(
    name='GetSessionCostRequest',
    full_name='grid.v1.GetSessionCostRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session_id',
            full_name='grid.v1.GetSessionCostRequest.session_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sessionId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.GetSessionCostRequest.start_timestamp',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='end_timestamp',
            full_name='grid.v1.GetSessionCostRequest.end_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='endTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2195,
    serialized_end=2383,
)

_GETSESSIONCOSTRESPONSE = _descriptor.Descriptor(
    name='GetSessionCostResponse',
    full_name='grid.v1.GetSessionCostResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cost',
            full_name='grid.v1.GetSessionCostResponse.cost',
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cost',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2385,
    serialized_end=2429,
)

_GETLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
_WATCHLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
_ARTIFACT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARTIFACT.fields_by_name['modified_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTARTIFACTSRESPONSE.fields_by_name['artifacts'].message_type = _ARTIFACT
_WATCHARTIFACTSRESPONSE.fields_by_name['artifacts'].message_type = _ARTIFACT
_GETEXPERIMENTMETRICSRESPONSE.fields_by_name['metrics'].message_type = _METRICS
_WATCHEXPERIMENTMETRICSRESPONSE.fields_by_name['metrics'].message_type = _METRICS
_GETEXPERIMENTCOSTREQUEST.fields_by_name['start_timestamp'
                                         ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETEXPERIMENTCOSTREQUEST.fields_by_name['end_timestamp'
                                         ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETSESSIONCOSTREQUEST.fields_by_name['start_timestamp'
                                      ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETSESSIONCOSTREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetLogsRequest'] = _GETLOGSREQUEST
DESCRIPTOR.message_types_by_name['GetLogsResponse'] = _GETLOGSRESPONSE
DESCRIPTOR.message_types_by_name['WatchLogsRequest'] = _WATCHLOGSREQUEST
DESCRIPTOR.message_types_by_name['WatchLogsResponse'] = _WATCHLOGSRESPONSE
DESCRIPTOR.message_types_by_name['Artifact'] = _ARTIFACT
DESCRIPTOR.message_types_by_name['ListArtifactsRequest'] = _LISTARTIFACTSREQUEST
DESCRIPTOR.message_types_by_name['ListArtifactsResponse'] = _LISTARTIFACTSRESPONSE
DESCRIPTOR.message_types_by_name['WatchArtifactsRequest'] = _WATCHARTIFACTSREQUEST
DESCRIPTOR.message_types_by_name['WatchArtifactsResponse'] = _WATCHARTIFACTSRESPONSE
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
DESCRIPTOR.message_types_by_name['GetExperimentMetricsRequest'] = _GETEXPERIMENTMETRICSREQUEST
DESCRIPTOR.message_types_by_name['GetExperimentMetricsResponse'] = _GETEXPERIMENTMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['ListAvailableMetricsRequest'] = _LISTAVAILABLEMETRICSREQUEST
DESCRIPTOR.message_types_by_name['ListAvailableMetricsResponse'] = _LISTAVAILABLEMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['WatchExperimentMetricsRequest'] = _WATCHEXPERIMENTMETRICSREQUEST
DESCRIPTOR.message_types_by_name['WatchExperimentMetricsResponse'] = _WATCHEXPERIMENTMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['GetExperimentCostRequest'] = _GETEXPERIMENTCOSTREQUEST
DESCRIPTOR.message_types_by_name['GetExperimentCostResponse'] = _GETEXPERIMENTCOSTRESPONSE
DESCRIPTOR.message_types_by_name['GetSessionCostRequest'] = _GETSESSIONCOSTREQUEST
DESCRIPTOR.message_types_by_name['GetSessionCostResponse'] = _GETSESSIONCOSTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLogsRequest = _reflection.GeneratedProtocolMessageType(
    'GetLogsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETLOGSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetLogsRequest)
    }
)
_sym_db.RegisterMessage(GetLogsRequest)

GetLogsResponse = _reflection.GeneratedProtocolMessageType(
    'GetLogsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETLOGSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetLogsResponse)
    }
)
_sym_db.RegisterMessage(GetLogsResponse)

WatchLogsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchLogsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHLOGSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchLogsRequest)
    }
)
_sym_db.RegisterMessage(WatchLogsRequest)

WatchLogsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchLogsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHLOGSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchLogsResponse)
    }
)
_sym_db.RegisterMessage(WatchLogsResponse)

Artifact = _reflection.GeneratedProtocolMessageType(
    'Artifact',
    (_message.Message, ),
    {
        'DESCRIPTOR': _ARTIFACT,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Artifact)
    }
)
_sym_db.RegisterMessage(Artifact)

ListArtifactsRequest = _reflection.GeneratedProtocolMessageType(
    'ListArtifactsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTARTIFACTSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListArtifactsRequest)
    }
)
_sym_db.RegisterMessage(ListArtifactsRequest)

ListArtifactsResponse = _reflection.GeneratedProtocolMessageType(
    'ListArtifactsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTARTIFACTSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListArtifactsResponse)
    }
)
_sym_db.RegisterMessage(ListArtifactsResponse)

WatchArtifactsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchArtifactsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHARTIFACTSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchArtifactsRequest)
    }
)
_sym_db.RegisterMessage(WatchArtifactsRequest)

WatchArtifactsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchArtifactsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHARTIFACTSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchArtifactsResponse)
    }
)
_sym_db.RegisterMessage(WatchArtifactsResponse)

Metrics = _reflection.GeneratedProtocolMessageType(
    'Metrics',
    (_message.Message, ),
    {
        'DESCRIPTOR': _METRICS,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Metrics)
    }
)
_sym_db.RegisterMessage(Metrics)

GetExperimentMetricsRequest = _reflection.GeneratedProtocolMessageType(
    'GetExperimentMetricsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETEXPERIMENTMETRICSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentMetricsRequest)
    }
)
_sym_db.RegisterMessage(GetExperimentMetricsRequest)

GetExperimentMetricsResponse = _reflection.GeneratedProtocolMessageType(
    'GetExperimentMetricsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETEXPERIMENTMETRICSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentMetricsResponse)
    }
)
_sym_db.RegisterMessage(GetExperimentMetricsResponse)

ListAvailableMetricsRequest = _reflection.GeneratedProtocolMessageType(
    'ListAvailableMetricsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTAVAILABLEMETRICSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListAvailableMetricsRequest)
    }
)
_sym_db.RegisterMessage(ListAvailableMetricsRequest)

ListAvailableMetricsResponse = _reflection.GeneratedProtocolMessageType(
    'ListAvailableMetricsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTAVAILABLEMETRICSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListAvailableMetricsResponse)
    }
)
_sym_db.RegisterMessage(ListAvailableMetricsResponse)

WatchExperimentMetricsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchExperimentMetricsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHEXPERIMENTMETRICSREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchExperimentMetricsRequest)
    }
)
_sym_db.RegisterMessage(WatchExperimentMetricsRequest)

WatchExperimentMetricsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchExperimentMetricsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHEXPERIMENTMETRICSRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchExperimentMetricsResponse)
    }
)
_sym_db.RegisterMessage(WatchExperimentMetricsResponse)

GetExperimentCostRequest = _reflection.GeneratedProtocolMessageType(
    'GetExperimentCostRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETEXPERIMENTCOSTREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentCostRequest)
    }
)
_sym_db.RegisterMessage(GetExperimentCostRequest)

GetExperimentCostResponse = _reflection.GeneratedProtocolMessageType(
    'GetExperimentCostResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETEXPERIMENTCOSTRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentCostResponse)
    }
)
_sym_db.RegisterMessage(GetExperimentCostResponse)

GetSessionCostRequest = _reflection.GeneratedProtocolMessageType(
    'GetSessionCostRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETSESSIONCOSTREQUEST,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetSessionCostRequest)
    }
)
_sym_db.RegisterMessage(GetSessionCostRequest)

GetSessionCostResponse = _reflection.GeneratedProtocolMessageType(
    'GetSessionCostResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETSESSIONCOSTRESPONSE,
        '__module__': 'grid.v1.experiment_details_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetSessionCostResponse)
    }
)
_sym_db.RegisterMessage(GetSessionCostResponse)

DESCRIPTOR._options = None

_EXPERIMENTDETAILSSERVICE = _descriptor.ServiceDescriptor(
    name='ExperimentDetailsService',
    full_name='grid.v1.ExperimentDetailsService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2432,
    serialized_end=3247,
    methods=[
        _descriptor.MethodDescriptor(
            name='GetLogs',
            full_name='grid.v1.ExperimentDetailsService.GetLogs',
            index=0,
            containing_service=None,
            input_type=_GETLOGSREQUEST,
            output_type=_GETLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchLogs',
            full_name='grid.v1.ExperimentDetailsService.WatchLogs',
            index=1,
            containing_service=None,
            input_type=_WATCHLOGSREQUEST,
            output_type=_WATCHLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListArtifacts',
            full_name='grid.v1.ExperimentDetailsService.ListArtifacts',
            index=2,
            containing_service=None,
            input_type=_LISTARTIFACTSREQUEST,
            output_type=_LISTARTIFACTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchArtifacts',
            full_name='grid.v1.ExperimentDetailsService.WatchArtifacts',
            index=3,
            containing_service=None,
            input_type=_WATCHARTIFACTSREQUEST,
            output_type=_WATCHARTIFACTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetExperimentMetrics',
            full_name='grid.v1.ExperimentDetailsService.GetExperimentMetrics',
            index=4,
            containing_service=None,
            input_type=_GETEXPERIMENTMETRICSREQUEST,
            output_type=_GETEXPERIMENTMETRICSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListAvailableMetrics',
            full_name='grid.v1.ExperimentDetailsService.ListAvailableMetrics',
            index=5,
            containing_service=None,
            input_type=_LISTAVAILABLEMETRICSREQUEST,
            output_type=_LISTAVAILABLEMETRICSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchExperimentMetrics',
            full_name='grid.v1.ExperimentDetailsService.WatchExperimentMetrics',
            index=6,
            containing_service=None,
            input_type=_WATCHEXPERIMENTMETRICSREQUEST,
            output_type=_WATCHEXPERIMENTMETRICSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetExperimentCost',
            full_name='grid.v1.ExperimentDetailsService.GetExperimentCost',
            index=7,
            containing_service=None,
            input_type=_GETEXPERIMENTCOSTREQUEST,
            output_type=_GETEXPERIMENTCOSTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetSessionCost',
            full_name='grid.v1.ExperimentDetailsService.GetSessionCost',
            index=8,
            containing_service=None,
            input_type=_GETSESSIONCOSTREQUEST,
            output_type=_GETSESSIONCOSTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_EXPERIMENTDETAILSSERVICE)

DESCRIPTOR.services_by_name['ExperimentDetailsService'] = _EXPERIMENTDETAILSSERVICE

# @@protoc_insertion_point(module_scope)
