# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/experiment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

from grid.protos.grid.v1 import experiment_pb2 as grid_dot_v1_dot_experiment__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/experiment_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n grid/v1/experiment_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x18grid/v1/experiment.proto\"N\n\x17\x43reateExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"O\n\x18\x43reateExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"&\n\x14GetExperimentRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"L\n\x15GetExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"\xc0\x02\n\x16ListExperimentsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x15\n\x06run_id\x18\x04 \x01(\tR\x05runId\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\x12\x33\n\x08phase_in\x18\x07 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\x07phaseIn\x12:\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\nphaseNotIn\"\xa0\x01\n\x17ListExperimentsResponse\x12\x33\n\nexperiment\x18\x01 \x03(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"N\n\x17UpdateExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"O\n\x18UpdateExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"T\n\x1dUpdateExperimentStatusRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"U\n\x1eUpdateExperimentStatusResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"N\n\x17\x44\x65leteExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"O\n\x18\x44\x65leteExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"\x9a\x02\n\x17WatchExperimentsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x15\n\x06run_id\x18\x04 \x01(\tR\x05runId\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\x12\x33\n\x08phase_in\x18\x07 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\x07phaseIn\x12:\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\nphaseNotIn\"\xa7\x01\n\x18WatchExperimentsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12\x33\n\nexperiment\x18\x03 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment2\x94\x05\n\x11\x45xperimentService\x12Y\n\x10\x43reateExperiment\x12 .grid.v1.CreateExperimentRequest\x1a!.grid.v1.CreateExperimentResponse\"\x00\x12P\n\rGetExperiment\x12\x1d.grid.v1.GetExperimentRequest\x1a\x1e.grid.v1.GetExperimentResponse\"\x00\x12V\n\x0fListExperiments\x12\x1f.grid.v1.ListExperimentsRequest\x1a .grid.v1.ListExperimentsResponse\"\x00\x12Y\n\x10UpdateExperiment\x12 .grid.v1.UpdateExperimentRequest\x1a!.grid.v1.UpdateExperimentResponse\"\x00\x12i\n\x16UpdateExperimentStatus\x12&.grid.v1.UpdateExperimentStatusRequest\x1a\'.grid.v1.UpdateExperimentStatusResponse\x12Y\n\x10\x44\x65leteExperiment\x12 .grid.v1.DeleteExperimentRequest\x1a!.grid.v1.DeleteExperimentResponse\"\x00\x12Y\n\x10WatchExperiments\x12 .grid.v1.WatchExperimentsRequest\x1a!.grid.v1.WatchExperimentsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_experiment__pb2.DESCRIPTOR,
    ]
)

_CREATEEXPERIMENTREQUEST = _descriptor.Descriptor(
    name='CreateExperimentRequest',
    full_name='grid.v1.CreateExperimentRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.CreateExperimentRequest.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=125,
    serialized_end=203,
)

_CREATEEXPERIMENTRESPONSE = _descriptor.Descriptor(
    name='CreateExperimentResponse',
    full_name='grid.v1.CreateExperimentResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.CreateExperimentResponse.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=205,
    serialized_end=284,
)

_GETEXPERIMENTREQUEST = _descriptor.Descriptor(
    name='GetExperimentRequest',
    full_name='grid.v1.GetExperimentRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetExperimentRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=286,
    serialized_end=324,
)

_GETEXPERIMENTRESPONSE = _descriptor.Descriptor(
    name='GetExperimentResponse',
    full_name='grid.v1.GetExperimentResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.GetExperimentResponse.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=326,
    serialized_end=402,
)

_LISTEXPERIMENTSREQUEST = _descriptor.Descriptor(
    name='ListExperimentsRequest',
    full_name='grid.v1.ListExperimentsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListExperimentsRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListExperimentsRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListExperimentsRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='run_id',
            full_name='grid.v1.ListExperimentsRequest.run_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='runId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListExperimentsRequest.user_id',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ListExperimentsRequest.cluster_id',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.ListExperimentsRequest.phase_in',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.ListExperimentsRequest.phase_not_in',
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=405,
    serialized_end=725,
)

_LISTEXPERIMENTSRESPONSE = _descriptor.Descriptor(
    name='ListExperimentsResponse',
    full_name='grid.v1.ListExperimentsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.ListExperimentsResponse.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListExperimentsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListExperimentsResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=728,
    serialized_end=888,
)

_UPDATEEXPERIMENTREQUEST = _descriptor.Descriptor(
    name='UpdateExperimentRequest',
    full_name='grid.v1.UpdateExperimentRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.UpdateExperimentRequest.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=890,
    serialized_end=968,
)

_UPDATEEXPERIMENTRESPONSE = _descriptor.Descriptor(
    name='UpdateExperimentResponse',
    full_name='grid.v1.UpdateExperimentResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.UpdateExperimentResponse.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=970,
    serialized_end=1049,
)

_UPDATEEXPERIMENTSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateExperimentStatusRequest',
    full_name='grid.v1.UpdateExperimentStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.UpdateExperimentStatusRequest.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1051,
    serialized_end=1135,
)

_UPDATEEXPERIMENTSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateExperimentStatusResponse',
    full_name='grid.v1.UpdateExperimentStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.UpdateExperimentStatusResponse.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1137,
    serialized_end=1222,
)

_DELETEEXPERIMENTREQUEST = _descriptor.Descriptor(
    name='DeleteExperimentRequest',
    full_name='grid.v1.DeleteExperimentRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.DeleteExperimentRequest.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1224,
    serialized_end=1302,
)

_DELETEEXPERIMENTRESPONSE = _descriptor.Descriptor(
    name='DeleteExperimentResponse',
    full_name='grid.v1.DeleteExperimentResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.DeleteExperimentResponse.experiment',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1304,
    serialized_end=1383,
)

_WATCHEXPERIMENTSREQUEST = _descriptor.Descriptor(
    name='WatchExperimentsRequest',
    full_name='grid.v1.WatchExperimentsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchExperimentsRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchExperimentsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='run_id',
            full_name='grid.v1.WatchExperimentsRequest.run_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='runId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchExperimentsRequest.user_id',
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.WatchExperimentsRequest.cluster_id',
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.WatchExperimentsRequest.phase_in',
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.WatchExperimentsRequest.phase_not_in',
            index=6,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1386,
    serialized_end=1668,
)

_WATCHEXPERIMENTSRESPONSE = _descriptor.Descriptor(
    name='WatchExperimentsResponse',
    full_name='grid.v1.WatchExperimentsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchExperimentsResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchExperimentsResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='experiment',
            full_name='grid.v1.WatchExperimentsResponse.experiment',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1671,
    serialized_end=1838,
)

_CREATEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_CREATEEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_GETEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_LISTEXPERIMENTSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_LISTEXPERIMENTSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_LISTEXPERIMENTSRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTSTATUSREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTSTATUSRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_DELETEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_DELETEEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_WATCHEXPERIMENTSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_WATCHEXPERIMENTSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_WATCHEXPERIMENTSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHEXPERIMENTSRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
DESCRIPTOR.message_types_by_name['CreateExperimentRequest'] = _CREATEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['CreateExperimentResponse'] = _CREATEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetExperimentRequest'] = _GETEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['GetExperimentResponse'] = _GETEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['ListExperimentsRequest'] = _LISTEXPERIMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListExperimentsResponse'] = _LISTEXPERIMENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateExperimentRequest'] = _UPDATEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateExperimentResponse'] = _UPDATEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateExperimentStatusRequest'] = _UPDATEEXPERIMENTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateExperimentStatusResponse'] = _UPDATEEXPERIMENTSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteExperimentRequest'] = _DELETEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteExperimentResponse'] = _DELETEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['WatchExperimentsRequest'] = _WATCHEXPERIMENTSREQUEST
DESCRIPTOR.message_types_by_name['WatchExperimentsResponse'] = _WATCHEXPERIMENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateExperimentRequest = _reflection.GeneratedProtocolMessageType(
    'CreateExperimentRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATEEXPERIMENTREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateExperimentRequest)
    }
)
_sym_db.RegisterMessage(CreateExperimentRequest)

CreateExperimentResponse = _reflection.GeneratedProtocolMessageType(
    'CreateExperimentResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATEEXPERIMENTRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateExperimentResponse)
    }
)
_sym_db.RegisterMessage(CreateExperimentResponse)

GetExperimentRequest = _reflection.GeneratedProtocolMessageType(
    'GetExperimentRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETEXPERIMENTREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentRequest)
    }
)
_sym_db.RegisterMessage(GetExperimentRequest)

GetExperimentResponse = _reflection.GeneratedProtocolMessageType(
    'GetExperimentResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETEXPERIMENTRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentResponse)
    }
)
_sym_db.RegisterMessage(GetExperimentResponse)

ListExperimentsRequest = _reflection.GeneratedProtocolMessageType(
    'ListExperimentsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTEXPERIMENTSREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListExperimentsRequest)
    }
)
_sym_db.RegisterMessage(ListExperimentsRequest)

ListExperimentsResponse = _reflection.GeneratedProtocolMessageType(
    'ListExperimentsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTEXPERIMENTSRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListExperimentsResponse)
    }
)
_sym_db.RegisterMessage(ListExperimentsResponse)

UpdateExperimentRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateExperimentRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEEXPERIMENTREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentRequest)
    }
)
_sym_db.RegisterMessage(UpdateExperimentRequest)

UpdateExperimentResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateExperimentResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEEXPERIMENTRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentResponse)
    }
)
_sym_db.RegisterMessage(UpdateExperimentResponse)

UpdateExperimentStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateExperimentStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEEXPERIMENTSTATUSREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateExperimentStatusRequest)

UpdateExperimentStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateExperimentStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEEXPERIMENTSTATUSRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateExperimentStatusResponse)

DeleteExperimentRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteExperimentRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETEEXPERIMENTREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteExperimentRequest)
    }
)
_sym_db.RegisterMessage(DeleteExperimentRequest)

DeleteExperimentResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteExperimentResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETEEXPERIMENTRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteExperimentResponse)
    }
)
_sym_db.RegisterMessage(DeleteExperimentResponse)

WatchExperimentsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchExperimentsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHEXPERIMENTSREQUEST,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchExperimentsRequest)
    }
)
_sym_db.RegisterMessage(WatchExperimentsRequest)

WatchExperimentsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchExperimentsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHEXPERIMENTSRESPONSE,
        '__module__': 'grid.v1.experiment_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchExperimentsResponse)
    }
)
_sym_db.RegisterMessage(WatchExperimentsResponse)

DESCRIPTOR._options = None

_EXPERIMENTSERVICE = _descriptor.ServiceDescriptor(
    name='ExperimentService',
    full_name='grid.v1.ExperimentService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1841,
    serialized_end=2501,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateExperiment',
            full_name='grid.v1.ExperimentService.CreateExperiment',
            index=0,
            containing_service=None,
            input_type=_CREATEEXPERIMENTREQUEST,
            output_type=_CREATEEXPERIMENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetExperiment',
            full_name='grid.v1.ExperimentService.GetExperiment',
            index=1,
            containing_service=None,
            input_type=_GETEXPERIMENTREQUEST,
            output_type=_GETEXPERIMENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListExperiments',
            full_name='grid.v1.ExperimentService.ListExperiments',
            index=2,
            containing_service=None,
            input_type=_LISTEXPERIMENTSREQUEST,
            output_type=_LISTEXPERIMENTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateExperiment',
            full_name='grid.v1.ExperimentService.UpdateExperiment',
            index=3,
            containing_service=None,
            input_type=_UPDATEEXPERIMENTREQUEST,
            output_type=_UPDATEEXPERIMENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateExperimentStatus',
            full_name='grid.v1.ExperimentService.UpdateExperimentStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATEEXPERIMENTSTATUSREQUEST,
            output_type=_UPDATEEXPERIMENTSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteExperiment',
            full_name='grid.v1.ExperimentService.DeleteExperiment',
            index=5,
            containing_service=None,
            input_type=_DELETEEXPERIMENTREQUEST,
            output_type=_DELETEEXPERIMENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchExperiments',
            full_name='grid.v1.ExperimentService.WatchExperiments',
            index=6,
            containing_service=None,
            input_type=_WATCHEXPERIMENTSREQUEST,
            output_type=_WATCHEXPERIMENTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_EXPERIMENTSERVICE)

DESCRIPTOR.services_by_name['ExperimentService'] = _EXPERIMENTSERVICE

# @@protoc_insertion_point(module_scope)
