# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/tensorboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import tensorboard_pb2 as grid_dot_v1_dot_tensorboard__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/tensorboard_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n!grid/v1/tensorboard_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x19grid/v1/tensorboard.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"R\n\x18\x43reateTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19\x43reateTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\'\n\x15GetTensorboardRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x16GetTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\xef\x02\n\x17ListTensorboardsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x41\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x12\x34\n\x08phase_in\x18\x07 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\x07phaseIn\x12;\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\nphaseNotIn\"\xa4\x01\n\x18ListTensorboardsResponse\x12\x36\n\x0btensorboard\x18\x01 \x03(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"R\n\x18UpdateTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19UpdateTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"X\n\x1eUpdateTensorboardStatusRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"Y\n\x1fUpdateTensorboardStatusResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"R\n\x18\x44\x65leteTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19\x44\x65leteTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\xc9\x02\n\x18WatchTensorboardsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x41\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x12\x34\n\x08phase_in\x18\x07 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\x07phaseIn\x12;\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\nphaseNotIn\"\xab\x01\n\x19WatchTensorboardsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12\x36\n\x0btensorboard\x18\x03 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard2\xfc\x06\n\x12TensorboardService\x12|\n\x11\x43reateTensorboard\x12!.grid.v1.CreateTensorboardRequest\x1a\".grid.v1.CreateTensorboardResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/core/tensorboards:\x01*\x12u\n\x0eGetTensorboard\x12\x1e.grid.v1.GetTensorboardRequest\x1a\x1f.grid.v1.GetTensorboardResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/core/tensorboards/{id}\x12v\n\x10ListTensorboards\x12 .grid.v1.ListTensorboardsRequest\x1a!.grid.v1.ListTensorboardsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/core/tensorboards\x12\x96\x01\n\x11UpdateTensorboard\x12!.grid.v1.UpdateTensorboardRequest\x1a\".grid.v1.UpdateTensorboardResponse\":\x82\xd3\xe4\x93\x02\x34\x1a//v1/core/tensorboards/{tensorboard.metadata.id}:\x01*\x12l\n\x17UpdateTensorboardStatus\x12\'.grid.v1.UpdateTensorboardStatusRequest\x1a(.grid.v1.UpdateTensorboardStatusResponse\x12\x93\x01\n\x11\x44\x65leteTensorboard\x12!.grid.v1.DeleteTensorboardRequest\x1a\".grid.v1.DeleteTensorboardResponse\"7\x82\xd3\xe4\x93\x02\x31*//v1/core/tensorboards/{tensorboard.metadata.id}\x12\\\n\x11WatchTensorboards\x12!.grid.v1.WatchTensorboardsRequest\x1a\".grid.v1.WatchTensorboardsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_tensorboard__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ]
)

_CREATETENSORBOARDREQUEST = _descriptor.Descriptor(
    name='CreateTensorboardRequest',
    full_name='grid.v1.CreateTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.CreateTensorboardRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=160,
    serialized_end=242,
)

_CREATETENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='CreateTensorboardResponse',
    full_name='grid.v1.CreateTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.CreateTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=244,
    serialized_end=327,
)

_GETTENSORBOARDREQUEST = _descriptor.Descriptor(
    name='GetTensorboardRequest',
    full_name='grid.v1.GetTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetTensorboardRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=329,
    serialized_end=368,
)

_GETTENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='GetTensorboardResponse',
    full_name='grid.v1.GetTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.GetTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=370,
    serialized_end=450,
)

_LISTTENSORBOARDSREQUEST = _descriptor.Descriptor(
    name='ListTensorboardsRequest',
    full_name='grid.v1.ListTensorboardsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListTensorboardsRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListTensorboardsRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListTensorboardsRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListTensorboardsRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ListTensorboardsRequest.cluster_id',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='created_before',
            full_name='grid.v1.ListTensorboardsRequest.created_before',
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='createdBefore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.ListTensorboardsRequest.phase_in',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.ListTensorboardsRequest.phase_not_in',
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=453,
    serialized_end=820,
)

_LISTTENSORBOARDSRESPONSE = _descriptor.Descriptor(
    name='ListTensorboardsResponse',
    full_name='grid.v1.ListTensorboardsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.ListTensorboardsResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListTensorboardsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListTensorboardsResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=823,
    serialized_end=987,
)

_UPDATETENSORBOARDREQUEST = _descriptor.Descriptor(
    name='UpdateTensorboardRequest',
    full_name='grid.v1.UpdateTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=989,
    serialized_end=1071,
)

_UPDATETENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='UpdateTensorboardResponse',
    full_name='grid.v1.UpdateTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1073,
    serialized_end=1156,
)

_UPDATETENSORBOARDSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateTensorboardStatusRequest',
    full_name='grid.v1.UpdateTensorboardStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardStatusRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1158,
    serialized_end=1246,
)

_UPDATETENSORBOARDSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateTensorboardStatusResponse',
    full_name='grid.v1.UpdateTensorboardStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardStatusResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1248,
    serialized_end=1337,
)

_DELETETENSORBOARDREQUEST = _descriptor.Descriptor(
    name='DeleteTensorboardRequest',
    full_name='grid.v1.DeleteTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.DeleteTensorboardRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1339,
    serialized_end=1421,
)

_DELETETENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='DeleteTensorboardResponse',
    full_name='grid.v1.DeleteTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.DeleteTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1423,
    serialized_end=1506,
)

_WATCHTENSORBOARDSREQUEST = _descriptor.Descriptor(
    name='WatchTensorboardsRequest',
    full_name='grid.v1.WatchTensorboardsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchTensorboardsRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchTensorboardsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchTensorboardsRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.WatchTensorboardsRequest.cluster_id',
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='created_before',
            full_name='grid.v1.WatchTensorboardsRequest.created_before',
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='createdBefore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.WatchTensorboardsRequest.phase_in',
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.WatchTensorboardsRequest.phase_not_in',
            index=6,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1509,
    serialized_end=1838,
)

_WATCHTENSORBOARDSRESPONSE = _descriptor.Descriptor(
    name='WatchTensorboardsResponse',
    full_name='grid.v1.WatchTensorboardsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchTensorboardsResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchTensorboardsResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.WatchTensorboardsResponse.tensorboard',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1841,
    serialized_end=2012,
)

_CREATETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_CREATETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_GETTENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_LISTTENSORBOARDSREQUEST.fields_by_name['created_before'
                                        ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTENSORBOARDSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_LISTTENSORBOARDSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_LISTTENSORBOARDSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDSTATUSREQUEST.fields_by_name['tensorboard'
                                               ].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDSTATUSRESPONSE.fields_by_name['tensorboard'
                                                ].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_DELETETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_DELETETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_WATCHTENSORBOARDSREQUEST.fields_by_name['created_before'
                                         ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WATCHTENSORBOARDSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_WATCHTENSORBOARDSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_WATCHTENSORBOARDSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHTENSORBOARDSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
DESCRIPTOR.message_types_by_name['CreateTensorboardRequest'] = _CREATETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['CreateTensorboardResponse'] = _CREATETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['GetTensorboardRequest'] = _GETTENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['GetTensorboardResponse'] = _GETTENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['ListTensorboardsRequest'] = _LISTTENSORBOARDSREQUEST
DESCRIPTOR.message_types_by_name['ListTensorboardsResponse'] = _LISTTENSORBOARDSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTensorboardRequest'] = _UPDATETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['UpdateTensorboardResponse'] = _UPDATETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTensorboardStatusRequest'] = _UPDATETENSORBOARDSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateTensorboardStatusResponse'] = _UPDATETENSORBOARDSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTensorboardRequest'] = _DELETETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['DeleteTensorboardResponse'] = _DELETETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['WatchTensorboardsRequest'] = _WATCHTENSORBOARDSREQUEST
DESCRIPTOR.message_types_by_name['WatchTensorboardsResponse'] = _WATCHTENSORBOARDSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'CreateTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATETENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateTensorboardRequest)
    }
)
_sym_db.RegisterMessage(CreateTensorboardRequest)

CreateTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'CreateTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATETENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateTensorboardResponse)
    }
)
_sym_db.RegisterMessage(CreateTensorboardResponse)

GetTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'GetTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETTENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetTensorboardRequest)
    }
)
_sym_db.RegisterMessage(GetTensorboardRequest)

GetTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'GetTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETTENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetTensorboardResponse)
    }
)
_sym_db.RegisterMessage(GetTensorboardResponse)

ListTensorboardsRequest = _reflection.GeneratedProtocolMessageType(
    'ListTensorboardsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTTENSORBOARDSREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListTensorboardsRequest)
    }
)
_sym_db.RegisterMessage(ListTensorboardsRequest)

ListTensorboardsResponse = _reflection.GeneratedProtocolMessageType(
    'ListTensorboardsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTTENSORBOARDSRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListTensorboardsResponse)
    }
)
_sym_db.RegisterMessage(ListTensorboardsResponse)

UpdateTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardRequest)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardRequest)

UpdateTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardResponse)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardResponse)

UpdateTensorboardStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDSTATUSREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardStatusRequest)

UpdateTensorboardStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDSTATUSRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardStatusResponse)

DeleteTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETETENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteTensorboardRequest)
    }
)
_sym_db.RegisterMessage(DeleteTensorboardRequest)

DeleteTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETETENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteTensorboardResponse)
    }
)
_sym_db.RegisterMessage(DeleteTensorboardResponse)

WatchTensorboardsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchTensorboardsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHTENSORBOARDSREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchTensorboardsRequest)
    }
)
_sym_db.RegisterMessage(WatchTensorboardsRequest)

WatchTensorboardsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchTensorboardsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHTENSORBOARDSRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchTensorboardsResponse)
    }
)
_sym_db.RegisterMessage(WatchTensorboardsResponse)

DESCRIPTOR._options = None

_TENSORBOARDSERVICE = _descriptor.ServiceDescriptor(
    name='TensorboardService',
    full_name='grid.v1.TensorboardService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2015,
    serialized_end=2907,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateTensorboard',
            full_name='grid.v1.TensorboardService.CreateTensorboard',
            index=0,
            containing_service=None,
            input_type=_CREATETENSORBOARDREQUEST,
            output_type=_CREATETENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\002\032\"\025/v1/core/tensorboards:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetTensorboard',
            full_name='grid.v1.TensorboardService.GetTensorboard',
            index=1,
            containing_service=None,
            input_type=_GETTENSORBOARDREQUEST,
            output_type=_GETTENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\002\034\022\032/v1/core/tensorboards/{id}',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListTensorboards',
            full_name='grid.v1.TensorboardService.ListTensorboards',
            index=2,
            containing_service=None,
            input_type=_LISTTENSORBOARDSREQUEST,
            output_type=_LISTTENSORBOARDSRESPONSE,
            serialized_options=b'\202\323\344\223\002\027\022\025/v1/core/tensorboards',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateTensorboard',
            full_name='grid.v1.TensorboardService.UpdateTensorboard',
            index=3,
            containing_service=None,
            input_type=_UPDATETENSORBOARDREQUEST,
            output_type=_UPDATETENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\0024\032//v1/core/tensorboards/{tensorboard.metadata.id}:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateTensorboardStatus',
            full_name='grid.v1.TensorboardService.UpdateTensorboardStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATETENSORBOARDSTATUSREQUEST,
            output_type=_UPDATETENSORBOARDSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteTensorboard',
            full_name='grid.v1.TensorboardService.DeleteTensorboard',
            index=5,
            containing_service=None,
            input_type=_DELETETENSORBOARDREQUEST,
            output_type=_DELETETENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\0021*//v1/core/tensorboards/{tensorboard.metadata.id}',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchTensorboards',
            full_name='grid.v1.TensorboardService.WatchTensorboards',
            index=6,
            containing_service=None,
            input_type=_WATCHTENSORBOARDSREQUEST,
            output_type=_WATCHTENSORBOARDSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_TENSORBOARDSERVICE)

DESCRIPTOR.services_by_name['TensorboardService'] = _TENSORBOARDSERVICE

# @@protoc_insertion_point(module_scope)
