# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/image.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x13grid/v1/image.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"j\n\x12\x44\x65pendencyFileInfo\x12@\n\x0fpackage_manager\x18\x01 \x01(\x0e\x32\x17.grid.v1.PackageManagerR\x0epackageManager\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\"\xe0\x01\n\tImageSpec\x12\x16\n\x05image\x18\x01 \x01(\tH\x00R\x05image\x12 \n\ndockerfile\x18\x02 \x01(\tH\x00R\ndockerfile\x12\x35\n\x17on_image_build_commands\x18\x03 \x03(\tR\x14onImageBuildCommands\x12M\n\x14\x64\x65pendency_file_info\x18\x04 \x01(\x0b\x32\x1b.grid.v1.DependencyFileInfoR\x12\x64\x65pendencyFileInfoB\x13\n\x11\x62\x61se_image_source*e\n\x0ePackageManager\x12\x1f\n\x1bPACKAGE_MANAGER_UNSPECIFIED\x10\x00\x12\x17\n\x13PACKAGE_MANAGER_PIP\x10\x01\x12\x19\n\x15PACKAGE_MANAGER_CONDA\x10\x02\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_PACKAGEMANAGER = _descriptor.EnumDescriptor(
    name='PackageManager',
    full_name='grid.v1.PackageManager',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='PACKAGE_MANAGER_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='PACKAGE_MANAGER_PIP',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='PACKAGE_MANAGER_CONDA',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=451,
    serialized_end=552,
)
_sym_db.RegisterEnumDescriptor(_PACKAGEMANAGER)

PackageManager = enum_type_wrapper.EnumTypeWrapper(_PACKAGEMANAGER)
PACKAGE_MANAGER_UNSPECIFIED = 0
PACKAGE_MANAGER_PIP = 1
PACKAGE_MANAGER_CONDA = 2

_DEPENDENCYFILEINFO = _descriptor.Descriptor(
    name='DependencyFileInfo',
    full_name='grid.v1.DependencyFileInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='package_manager',
            full_name='grid.v1.DependencyFileInfo.package_manager',
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='packageManager',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='path',
            full_name='grid.v1.DependencyFileInfo.path',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='path',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=116,
    serialized_end=222,
)

_IMAGESPEC = _descriptor.Descriptor(
    name='ImageSpec',
    full_name='grid.v1.ImageSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='image',
            full_name='grid.v1.ImageSpec.image',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='image',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='dockerfile',
            full_name='grid.v1.ImageSpec.dockerfile',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dockerfile',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='on_image_build_commands',
            full_name='grid.v1.ImageSpec.on_image_build_commands',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='onImageBuildCommands',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='dependency_file_info',
            full_name='grid.v1.ImageSpec.dependency_file_info',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dependencyFileInfo',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='base_image_source',
            full_name='grid.v1.ImageSpec.base_image_source',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=225,
    serialized_end=449,
)

_DEPENDENCYFILEINFO.fields_by_name['package_manager'].enum_type = _PACKAGEMANAGER
_IMAGESPEC.fields_by_name['dependency_file_info'].message_type = _DEPENDENCYFILEINFO
_IMAGESPEC.oneofs_by_name['base_image_source'].fields.append(_IMAGESPEC.fields_by_name['image'])
_IMAGESPEC.fields_by_name['image'].containing_oneof = _IMAGESPEC.oneofs_by_name['base_image_source']
_IMAGESPEC.oneofs_by_name['base_image_source'].fields.append(_IMAGESPEC.fields_by_name['dockerfile'])
_IMAGESPEC.fields_by_name['dockerfile'].containing_oneof = _IMAGESPEC.oneofs_by_name['base_image_source']
DESCRIPTOR.message_types_by_name['DependencyFileInfo'] = _DEPENDENCYFILEINFO
DESCRIPTOR.message_types_by_name['ImageSpec'] = _IMAGESPEC
DESCRIPTOR.enum_types_by_name['PackageManager'] = _PACKAGEMANAGER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DependencyFileInfo = _reflection.GeneratedProtocolMessageType(
    'DependencyFileInfo',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DEPENDENCYFILEINFO,
        '__module__': 'grid.v1.image_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DependencyFileInfo)
    }
)
_sym_db.RegisterMessage(DependencyFileInfo)

ImageSpec = _reflection.GeneratedProtocolMessageType(
    'ImageSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _IMAGESPEC,
        '__module__': 'grid.v1.image_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ImageSpec)
    }
)
_sym_db.RegisterMessage(ImageSpec)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
