# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import user_service_pb2 as grid_dot_v1_dot_user__service__pb2


class UserServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateUser = channel.unary_unary(
            '/grid.v1.UserService/CreateUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.CreateUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.CreateUserResponse.FromString,
        )
        self.GetUser = channel.unary_unary(
            '/grid.v1.UserService/GetUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
        )
        self.ListUsers = channel.unary_unary(
            '/grid.v1.UserService/ListUsers',
            request_serializer=grid_dot_v1_dot_user__service__pb2.ListUsersRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.ListUsersResponse.FromString,
        )
        self.UpdateUser = channel.unary_unary(
            '/grid.v1.UserService/UpdateUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserResponse.FromString,
        )
        self.UpdateUserStatus = channel.unary_unary(
            '/grid.v1.UserService/UpdateUserStatus',
            request_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusResponse.FromString,
        )
        self.DeleteUser = channel.unary_unary(
            '/grid.v1.UserService/DeleteUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.DeleteUserResponse.FromString,
        )
        self.WatchUsers = channel.unary_stream(
            '/grid.v1.UserService/WatchUsers',
            request_serializer=grid_dot_v1_dot_user__service__pb2.WatchUsersRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.WatchUsersResponse.FromString,
        )
        self.StopUserWorkloads = channel.unary_unary(
            '/grid.v1.UserService/StopUserWorkloads',
            request_serializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsResponse.FromString,
        )


class UserServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUsers(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopUserWorkloads(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.CreateUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.CreateUserResponse.SerializeToString,
        ),
        'GetUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.GetUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.GetUserResponse.SerializeToString,
        ),
        'ListUsers':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListUsers,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.ListUsersRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.ListUsersResponse.SerializeToString,
        ),
        'UpdateUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserResponse.SerializeToString,
        ),
        'UpdateUserStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUserStatus,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusResponse.SerializeToString,
        ),
        'DeleteUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.DeleteUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.DeleteUserResponse.SerializeToString,
        ),
        'WatchUsers':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchUsers,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.WatchUsersRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.WatchUsersResponse.SerializeToString,
        ),
        'StopUserWorkloads':
        grpc.unary_unary_rpc_method_handler(
            servicer.StopUserWorkloads,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
