# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cost_controller_service_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/cost_controller_service_account.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n-grid/v1/cost_controller_service_account.proto\x12\x07grid.v1\"\x1e\n\x1c\x43ostControllerServiceAccountB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_COSTCONTROLLERSERVICEACCOUNT = _descriptor.Descriptor(
    name='CostControllerServiceAccount',
    full_name='grid.v1.CostControllerServiceAccount',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=58,
    serialized_end=88,
)

DESCRIPTOR.message_types_by_name['CostControllerServiceAccount'] = _COSTCONTROLLERSERVICEACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CostControllerServiceAccount = _reflection.GeneratedProtocolMessageType(
    'CostControllerServiceAccount',
    (_message.Message, ),
    {
        'DESCRIPTOR': _COSTCONTROLLERSERVICEACCOUNT,
        '__module__': 'grid.v1.cost_controller_service_account_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CostControllerServiceAccount)
    }
)
_sym_db.RegisterMessage(CostControllerServiceAccount)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
