# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import run_service_pb2 as grid_dot_v1_dot_run__service__pb2


class RunServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateRun = channel.unary_unary(
            '/grid.v1.RunService/CreateRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.CreateRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.CreateRunResponse.FromString,
        )
        self.GetRun = channel.unary_unary(
            '/grid.v1.RunService/GetRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.GetRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.GetRunResponse.FromString,
        )
        self.ListRuns = channel.unary_unary(
            '/grid.v1.RunService/ListRuns',
            request_serializer=grid_dot_v1_dot_run__service__pb2.ListRunsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.ListRunsResponse.FromString,
        )
        self.UpdateRun = channel.unary_unary(
            '/grid.v1.RunService/UpdateRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunResponse.FromString,
        )
        self.UpdateRunStatus = channel.unary_unary(
            '/grid.v1.RunService/UpdateRunStatus',
            request_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusResponse.FromString,
        )
        self.DeleteRun = channel.unary_unary(
            '/grid.v1.RunService/DeleteRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.DeleteRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.DeleteRunResponse.FromString,
        )
        self.WatchRuns = channel.unary_stream(
            '/grid.v1.RunService/WatchRuns',
            request_serializer=grid_dot_v1_dot_run__service__pb2.WatchRunsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.WatchRunsResponse.FromString,
        )


class RunServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRuns(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRunStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchRuns(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.CreateRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.CreateRunResponse.SerializeToString,
        ),
        'GetRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.GetRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.GetRunResponse.SerializeToString,
        ),
        'ListRuns':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListRuns,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.ListRunsRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.ListRunsResponse.SerializeToString,
        ),
        'UpdateRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunResponse.SerializeToString,
        ),
        'UpdateRunStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateRunStatus,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusResponse.SerializeToString,
        ),
        'DeleteRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.DeleteRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.DeleteRunResponse.SerializeToString,
        ),
        'WatchRuns':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchRuns,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.WatchRunsRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.WatchRunsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.RunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
