# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/tensorboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/tensorboard.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x19grid/v1/tensorboard.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x9e\x01\n\x0bTensorboard\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.grid.v1.TensorboardSpecR\x04spec\x12\x32\n\x06status\x18\x03 \x01(\x0b\x32\x1a.grid.v1.TensorboardStatusR\x06status\"B\n\x1bTensorboardExperimentConfig\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\"\xd1\x01\n\x0fTensorboardSpec\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x46\n\x0b\x65xperiments\x18\x03 \x03(\x0b\x32$.grid.v1.TensorboardExperimentConfigR\x0b\x65xperiments\x12>\n\rdesired_state\x18\x04 \x01(\x0e\x32\x19.grid.v1.TensorboardStateR\x0c\x64\x65siredState\"\xab\x01\n\x11TensorboardStatus\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x39\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12/\n\x05phase\x18\x04 \x01(\x0e\x32\x19.grid.v1.TensorboardStateR\x05phase*\xb0\x01\n\x10TensorboardState\x12!\n\x1dTENSORBOARD_STATE_UNSPECIFIED\x10\x00\x12\x1d\n\x19TENSORBOARD_STATE_PENDING\x10\x01\x12\x1d\n\x19TENSORBOARD_STATE_RUNNING\x10\x02\x12\x1d\n\x19TENSORBOARD_STATE_DELETED\x10\x03\x12\x1c\n\x18TENSORBOARD_STATE_FAILED\x10\x04\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_TENSORBOARDSTATE = _descriptor.EnumDescriptor(
    name='TensorboardState',
    full_name='grid.v1.TensorboardState',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_PENDING',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_RUNNING',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_DELETED',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_FAILED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=738,
    serialized_end=914,
)
_sym_db.RegisterEnumDescriptor(_TENSORBOARDSTATE)

TensorboardState = enum_type_wrapper.EnumTypeWrapper(_TENSORBOARDSTATE)
TENSORBOARD_STATE_UNSPECIFIED = 0
TENSORBOARD_STATE_PENDING = 1
TENSORBOARD_STATE_RUNNING = 2
TENSORBOARD_STATE_DELETED = 3
TENSORBOARD_STATE_FAILED = 4

_TENSORBOARD = _descriptor.Descriptor(
    name='Tensorboard',
    full_name='grid.v1.Tensorboard',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.Tensorboard.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='spec',
            full_name='grid.v1.Tensorboard.spec',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='spec',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.Tensorboard.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=123,
    serialized_end=281,
)

_TENSORBOARDEXPERIMENTCONFIG = _descriptor.Descriptor(
    name='TensorboardExperimentConfig',
    full_name='grid.v1.TensorboardExperimentConfig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.TensorboardExperimentConfig.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=283,
    serialized_end=349,
)

_TENSORBOARDSPEC = _descriptor.Descriptor(
    name='TensorboardSpec',
    full_name='grid.v1.TensorboardSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.TensorboardSpec.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.TensorboardSpec.cluster_id',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='experiments',
            full_name='grid.v1.TensorboardSpec.experiments',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiments',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state',
            full_name='grid.v1.TensorboardSpec.desired_state',
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredState',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=352,
    serialized_end=561,
)

_TENSORBOARDSTATUS = _descriptor.Descriptor(
    name='TensorboardStatus',
    full_name='grid.v1.TensorboardStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='url',
            full_name='grid.v1.TensorboardStatus.url',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='url',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='message',
            full_name='grid.v1.TensorboardStatus.message',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='message',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='updated_at',
            full_name='grid.v1.TensorboardStatus.updated_at',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='updatedAt',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase',
            full_name='grid.v1.TensorboardStatus.phase',
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phase',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=564,
    serialized_end=735,
)

_TENSORBOARD.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_TENSORBOARD.fields_by_name['spec'].message_type = _TENSORBOARDSPEC
_TENSORBOARD.fields_by_name['status'].message_type = _TENSORBOARDSTATUS
_TENSORBOARDSPEC.fields_by_name['experiments'].message_type = _TENSORBOARDEXPERIMENTCONFIG
_TENSORBOARDSPEC.fields_by_name['desired_state'].enum_type = _TENSORBOARDSTATE
_TENSORBOARDSTATUS.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TENSORBOARDSTATUS.fields_by_name['phase'].enum_type = _TENSORBOARDSTATE
DESCRIPTOR.message_types_by_name['Tensorboard'] = _TENSORBOARD
DESCRIPTOR.message_types_by_name['TensorboardExperimentConfig'] = _TENSORBOARDEXPERIMENTCONFIG
DESCRIPTOR.message_types_by_name['TensorboardSpec'] = _TENSORBOARDSPEC
DESCRIPTOR.message_types_by_name['TensorboardStatus'] = _TENSORBOARDSTATUS
DESCRIPTOR.enum_types_by_name['TensorboardState'] = _TENSORBOARDSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tensorboard = _reflection.GeneratedProtocolMessageType(
    'Tensorboard',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARD,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Tensorboard)
    }
)
_sym_db.RegisterMessage(Tensorboard)

TensorboardExperimentConfig = _reflection.GeneratedProtocolMessageType(
    'TensorboardExperimentConfig',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARDEXPERIMENTCONFIG,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TensorboardExperimentConfig)
    }
)
_sym_db.RegisterMessage(TensorboardExperimentConfig)

TensorboardSpec = _reflection.GeneratedProtocolMessageType(
    'TensorboardSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARDSPEC,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TensorboardSpec)
    }
)
_sym_db.RegisterMessage(TensorboardSpec)

TensorboardStatus = _reflection.GeneratedProtocolMessageType(
    'TensorboardStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARDSTATUS,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TensorboardStatus)
    }
)
_sym_db.RegisterMessage(TensorboardStatus)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
